==> aecu.core-5.0.0-sources.jar: de/valtech/aecu/core/groovy/console/bindings/provider/AecuStarImportExtensionProvider.java <==
/*
 * Copyright 2018 Valtech GmbH
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.valtech.aecu.core.groovy.console.bindings.provider;

import java.util.HashSet;
import java.util.Set;

import org.osgi.service.component.annotations.Component;

import com.icfolson.aem.groovy.console.api.StarImport;
import com.icfolson.aem.groovy.console.api.StarImportExtensionProvider;

import de.valtech.aecu.api.groovy.console.bindings.filters.FilterBy;

@Component(immediate = true)
public class AecuStarImportExtensionProvider implements StarImportExtensionProvider {

    @Override
    public Set<StarImport> getStarImports() {
        Set<StarImport> imports = new HashSet<>();
        imports.add(new StarImport(FilterBy.class.getPackage().getName(), "https://valtech.github.io/aem-easy-content-upgrade/"));
        return imports;
    }

}

==> aecu.core-6.5.2-sources.jar: de/valtech/aecu/core/groovy/console/bindings/provider/AecuStarImportExtensionProvider.java <==
/*
 * Copyright 2018 Valtech GmbH
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.valtech.aecu.core.groovy.console.bindings.provider;

import java.util.HashSet;
import java.util.Set;

import org.osgi.service.component.annotations.Component;

import be.orbinson.aem.groovy.console.api.StarImport;
import be.orbinson.aem.groovy.console.api.StarImportExtensionProvider;

import de.valtech.aecu.api.groovy.console.bindings.filters.FilterBy;

@Component(immediate = true, service = {StarImportExtensionProvider.class, AecuStarImportExtensionProvider.class})
public class AecuStarImportExtensionProvider implements StarImportExtensionProvider {

    @Override
    public Set<StarImport> getStarImports() {
        Set<StarImport> imports = new HashSet<>();
        imports.add(new StarImport(FilterBy.class.getPackage().getName(), "https://valtech.github.io/aem-easy-content-upgrade/"));
        return imports;
    }

}
